<?php

namespace Drupal\niobi_app;

use Drupal\niobi_app\Entity\NiobiApplicationInterface;
use Drupal\niobi_app\Entity\NiobiApplicationWorkflow;
use Drupal\niobi_app\Plugin\task\Bundle\ApplicationReviewTask;
use Drupal\niobi_app\Entity\NiobiApplication;
use Drupal\task\Entity\Task;
use Drupal\user\UserInterface;

class NiobiAppUtilities {

  /**
   * @param UserInterface $reviewer
   * @param NiobiApplicationInterface $application
   * @return bool
   *   FALSE means they are not excluded, and OK to assign.
   *   TRUE means they are excluded, and should not be assigned.
   */
  public static function ExcludedAsReviewer(UserInterface $reviewer, NiobiApplicationInterface $application) {
    return FALSE;
  }

  public static function getStageName($status) {
    $stages = [
      'nomination' => 'Nomination',
      'nomination_claim' => 'Claim Nomination',
      'application' => 'Application',
      'review' => 'In Review',
      'decision' => 'Decision Pending',
      'complete' => 'Complete',
    ];

    return $stages[$status];
  }

  /**
   * @param $status
   * @param NiobiApplicationInterface $application
   * @return string
   */
  public static function generateStageList($status, NiobiApplicationInterface $application) {
    $ret = '<div class="btn-group">';
    $nomination_form = $application->getCurrentApplicationStage()->getNominationForm();
    $stages = [
      'application' => 'Application',
      'review' => 'In Review',
      'decision' => 'Decision Pending',
      'complete' => 'Complete',
    ];
    if (!empty($nomination_form)) {
      $stages = [
        'nomination' => 'Nomination',
        'nomination_claim' => 'Claim Nomination',
        'application' => 'Application',
        'review' => 'In Review',
        'decision' => 'Decision Pending',
        'complete' => 'Complete',
      ];
    }
    $stage_identified = FALSE;

    foreach ($stages as $stage => $label) {
      if ($stage === $status) {
        $ret .= '<div class="btn btn-primary">' . $label . '</div>';
        $stage_identified = TRUE;
      }
      else {
        if ($stage_identified) {
          $ret .= '<div class="btn btn-default">' . $label . '</div>';
        }
        else {
          $ret .= '<div class="btn btn-info">' . $label . '</div>';
        }
      }
    }
    $ret .= '</div>';

    return $ret;
  }

  /**
   * @param NiobiApplication $application
   * @param NiobiApplicationWorkflow $workflow
   * @return array
   */
  public static function generateReviewAssignmentRenderArray (NiobiApplication $application, NiobiApplicationWorkflow $workflow) {
    if ($workflow->isReadyToUse()) {
      $status = $application->get('field_application_status')->getValue()[0]['value'];
      $status_name = t('Current Status') . ': ' . NiobiAppUtilities::getStageName($status);
      $output = [
        'header' => [
          '#type' => 'html_tag',
          '#tag' => 'p',
          'value' => [
            '#type' => 'html_tag',
            '#tag' => 'strong',
            '#value' => t($status_name),
          ],
        ],
      ];
      $query = \Drupal::entityQuery('task');
      $query->condition('type', 'application_review_task');
      $query->condition('field_application', $application->id());
      $result = $query->execute();
      if(count($result)) {
        foreach ($result as $assignment) {
          $task = Task::load($assignment);
          if ($task) {
            $task_status = ApplicationReviewTask::getReviewTaskStatus($task, $application);
            $add = [
              '#type' => 'html_tag',
              '#tag' => 'div',
              'value' => [
                '#type' => 'html_tag',
                '#tag' => 'span',
                '#value' => $task->label(),
              ],
            ];
            switch ($task_status) {
              case 'complete':
                $add['value']['#attributes'] = ['class' => 'btn btn-xs btn-success'];
                $output[$task->id()] = $add;
                break;
              case 'draft':
                $add['value']['#attributes'] = ['class' => 'btn btn-xs btn-warning'];
                $output[$task->id()] = $add;
                break;
              case 'not started':
                $add['value']['#attributes'] = ['class' => 'btn btn-xs btn-danger'];
                $output[$task->id()] = $add;
                break;
            }
          }
        }
      }
    }
    else {
      \Drupal::messenger()->addError('The application has not been fully set up. Please contact the form administrator.');
      $output = '<p><em>' . t('The application system is not fully set up.') . '</em></p>';
      return ['#type' => 'markup', '#markup' => $output];
    }

    return [$output];
  }

}